@@ -8,7 +8,7 @@ import owlready2
 from owlready2 import sync_reasoner
 from collections import OrderedDict
 
-from graph_creation.ontology_processing_utils import (
+from ontology_processing.graph_creation.ontology_processing_utils import (
     give_alias,
     save_test_ontology_to_json,
     save_graph_to_pickle,
